'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.USER_TYPING_TIMEOUT = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = actionForMessage;

var _utils = require('../reducers/utils');

var _client = require('@slack/client');

const USER_TYPING_TIMEOUT = exports.USER_TYPING_TIMEOUT = 3000;

/**
 * Creates an action for a real-time message from the socket, based on its
 * type and subtype, if applicable.
 *
 * @param  {String} type    The type of message
 * @param  {Object} message The message from the socket
 * @param  {String} userId  The ID of the active user
 * @param  {String} teamId  The ID of the active team
 *
 * @return {Object}         The created action
 */
function actionForMessage(type, message, userId, teamId) {
  let asyncAction = asyncActionForType(type, message);
  if (asyncAction) return asyncAction;

  let action = {
    message,
    type: type === _client.RTM_EVENTS.MESSAGE ? (0, _utils.actionTypeWithSubtype)(message.subtype) : type
  };

  return (0, _utils.actionNeedsSelfParameters)(type) ? _extends({}, action, { userId, teamId }) : action;
}

function asyncActionForType(type, message) {
  switch (type) {
    case _client.RTM_EVENTS.USER_TYPING:
      return dispatch => {
        dispatch({ type, message, isTyping: true });

        setTimeout(() => {
          dispatch({ type, message, isTyping: false });
        }, USER_TYPING_TIMEOUT);
      };
    default:
      return null;
  }
}