'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reduce;

var _client = require('@slack/client');

var _helpers = require('./helpers');

var _utils = require('./utils');

var _messagesReducer = require('./messages-reducer');

var _messagesReducer2 = _interopRequireDefault(_messagesReducer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function reduce() {
  let state = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  let action = arguments[1];

  if ((0, _utils.isHandledByMessagesReducer)(action.type)) {
    return (0, _messagesReducer2.default)(state, action);
  }

  let type = action.type;
  let message = action.message;


  switch (type) {
    case _helpers.RTM_START:
      return (0, _helpers.populateFromRtmStart)(state, action.data.groups);
    case _client.RTM_EVENTS.GROUP_JOINED:
    case _client.RTM_EVENTS.GROUP_RENAME:
      return (0, _helpers.addOrUpdateChannel)(state, message);
    case _client.RTM_EVENTS.GROUP_LEFT:
      return (0, _helpers.leaveChannel)(state, message, action.userId);
    case _client.RTM_EVENTS.GROUP_ARCHIVE:
      return (0, _helpers.archiveChannel)(state, message, true);
    case _client.RTM_EVENTS.GROUP_UNARCHIVE:
      return (0, _helpers.archiveChannel)(state, message, false);
    case _client.RTM_EVENTS.USER_TYPING:
      return (0, _helpers.userIsTyping)(state, message, action.isTyping);
    case _client.RTM_EVENTS.GROUP_OPEN:
    case _client.RTM_EVENTS.GROUP_CLOSE:
    case _client.RTM_EVENTS.GROUP_HISTORY_CHANGED:
    default:
      return state;
  }
}