'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = reduce;

var _client = require('@slack/client');

var _helpers = require('./helpers');

function reduce() {
  let state = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  let action = arguments[1];
  let type = action.type;
  let message = action.message;
  let teamId = action.teamId;


  switch (type) {
    case _helpers.RTM_START:
      return rtmStart(state, action.data.team);
    case _client.RTM_EVENTS.TEAM_PREF_CHANGE:
      return changePreference(state, message, teamId);
    case _client.RTM_EVENTS.TEAM_DOMAIN_CHANGE:
      return changeTeamDomain(state, message, teamId);
    case _client.RTM_EVENTS.TEAM_RENAME:
      return renameTeam(state, message, teamId);
    default:
      return state;
  }
}

function rtmStart(state, team) {
  return team ? _extends({}, state, {
    [team.id]: team
  }) : state;
}

function changePreference(state, _ref, teamId) {
  let name = _ref.name;
  let value = _ref.value;

  let team = state[teamId];

  return _extends({}, state, {
    [team.id]: _extends({}, team, {
      prefs: _extends({}, team.prefs, {
        [name]: value
      })
    })
  });
}

function changeTeamDomain(state, _ref2, teamId) {
  let domain = _ref2.domain;
  let url = _ref2.url;

  let team = state[teamId];

  return _extends({}, state, {
    [team.id]: _extends({}, team, {
      domain,
      url
    })
  });
}

function renameTeam(state, _ref3, teamId) {
  let name = _ref3.name;

  let team = state[teamId];

  return _extends({}, state, {
    [team.id]: _extends({}, team, {
      name
    })
  });
}