'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = reduce;

var _client = require('@slack/client');

var _helpers = require('./helpers');

/**
 * users: {
 *    <userId>: {
 *      name: '',
 *      team_id: ''.
 *      status: null,
 *      email: '',
 *      real_name: '',
 *      prefs: {},
 *      presence: '',
 *      is_admin: false,
 *      is_primary_owner: false,
 *      is_restricted: false,
 *      is_ultra_restricted: false,
 *      is_bot: false
 *    },
 *    ...
 * }
 */

function reduce() {
  let state = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  let action = arguments[1];

  switch (action.type) {
    case _helpers.RTM_START:
      return (0, _helpers.populateFromRtmStart)(state, action.data.users);
    case _client.RTM_EVENTS.USER_CHANGE:
    case _client.RTM_EVENTS.TEAM_JOIN:
      return addOrUpdateUser(state, action.message);
    case _client.RTM_EVENTS.PREF_CHANGE:
      return changePreference(state, action.message, action.userId);
    case _client.RTM_EVENTS.PRESENCE_CHANGE:
      return changePresence(state, action.message, action.message.user);
    case _client.RTM_EVENTS.MANUAL_PRESENCE_CHANGE:
      return changePresence(state, action.message, action.userId);
    default:
      return state;
  }
}

function addOrUpdateUser(state, _ref) {
  let user = _ref.user;

  let existingUser = state[user.id];

  return _extends({}, state, {
    [user.id]: _extends({}, existingUser, user)
  });
}

function changePreference(state, _ref2, userId) {
  let name = _ref2.name;
  let value = _ref2.value;

  let user = state[userId];

  return _extends({}, state, {
    [user.id]: _extends({}, user, {
      prefs: _extends({}, user.prefs, {
        [name]: value
      })
    })
  });
}

function changePresence(state, _ref3, userId) {
  let presence = _ref3.presence;

  let user = state[userId];

  return _extends({}, state, {
    [user.id]: _extends({}, user, {
      presence
    })
  });
}